%define _default_patch_fuzz 1

%define Werror_cflags %nil

%global __requires_exclude_from  %{_docdir}/%{name}

# Csound is really dumb about 64-bit
%ifarch x86_64 ia64 aarch64
%define build64bit 1
%define install64bit --word64
%define useDouble 1
%else
%define build64bit 0
%define install64bit %{nil}
%define useDouble 0
%endif

%define build_java 0
%{?_with_java: %{expand: %%global build_java 1}}

Summary:	A sound synthesis language and library
Name:		csound
Version:	6.15.0
Release:	%mkrel 1
License:	LGPLv2+
Group:		Sound/Utilities
URL:		http://csound.github.io/

Source0:	https://github.com/csound/csound/archive/%{version}/%{name}-%{version}.tar.gz
Source1:	https://github.com/csound/manual/releases/download/%{version}/Csound%{version}_manual_html.zip
# Some patches taken from the Fedora .spec - thanks!
Patch1:		0001-Add-support-for-using-xdg-open-for-opening-help.patch
Patch2:		0002-Default-to-PulseAudio.patch
Patch3:		0003-use-standard-plugins-path.patch
Patch4:		0004-fix-naming-conflicts.patch

BuildRequires:	cmake
BuildRequires:	swig
BuildRequires:	pkgconfig(bluez)
BuildRequires:	pkgconfig(sndfile)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(alsa)
BuildRequires:	pkgconfig(jack)
BuildRequires:	pkgconfig(libpulse)
BuildRequires:	pkgconfig(fluidsynth)
BuildRequires:	pkgconfig(liblo)
BuildRequires:	pkgconfig(dssi)
BuildRequires:	pkgconfig(samplerate)
BuildRequires:	portaudio-devel
BuildRequires:	portmidi-devel
BuildRequires:	fltk-devel
BuildRequires:	tkinter3
%if %{build_java}
BuildRequires:	java-devel
BuildRequires:	jpackage-utils
%endif
BuildRequires:	pkgconfig(libxslt)
BuildRequires:	pkgconfig(vorbis)
BuildRequires:	pkgconfig(ogg)
BuildRequires:	gettext-devel
BuildRequires:	gcc-c++
BuildRequires:	boost-devel
BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	docbook-style-xsl
BuildRequires:	xsltproc
BuildRequires:	python3-setuptools
BuildRequires:	python3-pygments
BuildRequires:	libgomp-devel
BuildRequires:	eigen3-devel
BuildRequires:	wiiuse-devel

# The lua bindings were removed in version 6.15 of csound.  These
# obsoletes can be removed in Mageia 9.
Obsoletes: %{name}-lua < 6.15.0-1

%global luaver %(lua -v | sed -r 's/Lua ([[:digit:]]+\\.[[:digit:]]+).*/\\1/')

%description
Csound is a sound and music synthesis system, providing facilities for
composition and performance over a wide range of platforms. It is not
restricted to any style of music, having been used for many years in
at least classical, pop, techno, ambient...

%package	devel
Summary:	Csound development files and libraries
Group:		Development/C
Requires:	%{name} = %{version}-%{release}
Obsoletes:	olpcsound-devel <= 5.10.90
Conflicts:	%{name}-python < 5.13.0-3

%description	devel
Contains headers and libraries for developing applications that use Csound.

%package -n	python3-csound
Summary:	Python Csound development files and libraries
Group:		Development/Python
%{?python_provide:%python_provide python3-csound}
Requires:	%{name} = %{version}-%{release}
Requires:	python3

Obsoletes:	csound-python < 6.10.0-2
Provides:	csound-python = %{version}-%{release}

%description -n	python3-csound
Contains Python language bindings for developing Python applications that
use Csound.

%if %{build_java}
%package	java
Summary:	Java Csound support
Group:		Development/Java
Requires:	%{name} = %{version}-%{release}
Requires:	java-headless
Requires:	jpackage-utils

%description	java
Contains Java language bindings for developing and running Java
applications that use Csound.

%package	javadoc
Summary:	API documentation for Java Csound support
Group:		Development/Java

%description	javadoc
API documentation for the %{name}-java package.
%endif

%package	fltk
Summary:	FLTK plugins for Csound
Group:		Sound/Utilities
Requires:	%{name} = %{version}-%{release}
Requires:	fltk

%description	fltk
Contains FLTK plugins for csound.

%package	jack
Summary:	Jack Audio plugins for Csound
Group:		Sound/Utilities
Requires:	%{name} = %{version}-%{release}
Requires:	jackit
Conflicts:	csound < 6.10.0-1

%description	jack
Contains Jack Audio plugins for Csound.

%package	fluidsynth
Summary:	Fluidsyth soundfont plugin for Csound
Group:		Sound/Utilities
Requires:	%{name} = %{version}-%{release}

%description	fluidsynth
Contains Fluidsynth soundfont plugin for Csound.

%package	dssi
Summary:	Disposable Soft Synth Interface (DSSI) plugin for Csound
Group:		Sound/Utilities
Requires:	%{name} = %{version}-%{release}
Requires:	dssi

%description	dssi
Disposable Soft Synth Interface (DSSI) plugin for Csound.

%package	osc
Summary:	Open Sound Control (OSC) plugin for Csound
Group:		Sound/Utilities
Requires:	%{name} = %{version}-%{release}

%description	osc
Open Sound Control (OSC) plugin for Csound.

%package	portaudio
Summary:	PortAudio plugin for Csound
Group:		Sound/Utilities
Requires:	%{name} = %{version}-%{release}

%description portaudio
PortAudio plugin for Csound.

%package	virtual-keyboard
Summary:	Virtual MIDI keyboard plugin for Csound
Group:		Sound/Utilities
Requires:	%{name} = %{version}-%{release}
Requires:	fltk

%description	virtual-keyboard
A virtual MIDI keyboard plugin for Csound.

%package wiimote
Summary:	Wiimote plugin for Csound
Group:		Sound/Utilities
Requires:	%{name} = %{version}-%{release}

%description	wiimote
A Wiimote plugin for Csound.

%package	doc
Summary:	Csound manual
Group:		Documentation
Obsoletes:	%{name}-manual
Requires:	%{name} >= %{version}-%{release}
BuildArch:	noarch

%description	doc
Canonical Reference Manual for Csound.


%prep
%autosetup -p1
# setup the manual
%setup -q -T -D -a 1

# Fix end of line encodings
%define fix_line_encoding() \
  sed -i.orig 's/\\r\\n/\\n/;s/\\r/\\n/g' %1; \
  touch -r %1.orig %1; \
  rm -f %1.orig;

for csd in $(find html/examples -name \*.csd); do
  %fix_line_encoding $csd
done

%fix_line_encoding html/examples/128,8-torus
%fix_line_encoding html/examples/128-spiral-8,16,128,2,1over2
%fix_line_encoding html/examples/128-stringcircular
%fix_line_encoding html/examples/string-128.matrix

# Fix spurious executable bits
chmod a-x html/examples/*

# make sure Python 3 is used
sed -i 's|find_package(PythonLibs 2.7)|find_package(PythonLibs %{python3_version})|' CMakeLists.txt

%build
%if "%{_libdir}" == "%{_prefix}/lib64"
    %global uselib64 ON
%else
    %global uselib64 OFF
%endif

# Terrible hack
%ifarch %{arm}
sed -i 's*//#define PFFFT_SIMD_DISABLE*#define PFFFT_SIMD_DISABLE*' OOps/pffft.c
%endif

%cmake -DUSE_LIB64:BOOL=%{uselib64} -Wno-dev \
%if %{build_java}
       -DBUILD_JAVA_INTERFACE:BOOL=ON \
%endif
       -DSWIG_ADD_LIBRARY:BOOL=OFF -DBUILD_JACK_OPCODES:BOOL=ON \
       -DPYTHON_MODULE_INSTALL_DIR:STRING="%{python3_sitearch}" \
%ifarch %{x86}
       -DHAS_SSE2:BOOL=OFF -DHAS_FPMATH_SSE:BOOL=OFF \
%endif
%ifarch %{arm}
       -DHAVE_NEON:BOOL=OFF \
%endif
       -DBUILD_STK_OPCODES:BOOL=ON -DBUILD_LINEAR_ALGEBRA_OPCODES:BOOL=OFF

%cmake_build

%install
%cmake_install

%if %{build_java}

# Fix the Java installation
install -dm 755 %{buildroot}%{_javadir}
(cd %{buildroot}%{_javadir}; ln -s %{_libdir}/%{name}/java/csnd.jar .)

%endif


# Help the debuginfo generator
ln -s ../csound_orclex.c Engine/csound_orclex.c
ln -s ../csound_prelex.c Engine/csound_prelex.c

rm -rf %{buildroot}%{_datadir}/cmake/Csound/
rm -rf %{buildroot}%{_datadir}/samples/

%find_lang %{name}6

%files -f %{name}6.lang
%license COPYING
%doc README.md Release_Notes
%{_bindir}/atsa
%{_bindir}/cs
%{_bindir}/csanalyze
%{_bindir}/csb64enc
%{_bindir}/csbeats
%{_bindir}/csdebugger
%{_bindir}/csound
%{_bindir}/cvanal
%{_bindir}/dnoise
%{_bindir}/cs-envext
%{_bindir}/cs-extract
%{_bindir}/cs-extractor
%{_bindir}/het_export
%{_bindir}/het_import
%{_bindir}/hetro
%{_bindir}/lpanal
%{_bindir}/lpc_export
%{_bindir}/lpc_import
%{_bindir}/makecsd
%{_bindir}/cs-mixer
%{_bindir}/pvanal
%{_bindir}/pv_export
%{_bindir}/pv_import
%{_bindir}/pvlook
%{_bindir}/cs-scale
%{_bindir}/cs-scot
%{_bindir}/scsort
%{_bindir}/sdif2ad
%{_bindir}/cs-sndinfo
%{_bindir}/cs-srconv
%{_bindir}/cs-src_conv
%{_libdir}/lib%{name}64.so.6.0
%{_libdir}/libcsnd6.so.6.0
%dir %{_libdir}/%{name}/plugins-6.0
%{_libdir}/%{name}/plugins-6.0/libampmidid.so
%{_libdir}/%{name}/plugins-6.0/libarrayops.so
%{_libdir}/%{name}/plugins-6.0/libbeosc.so
%{_libdir}/%{name}/plugins-6.0/libbuchla.so
%{_libdir}/%{name}/plugins-6.0/libcellular.so
%{_libdir}/%{name}/plugins-6.0/libchua.so
%{_libdir}/%{name}/plugins-6.0/libcontrol.so
%{_libdir}/%{name}/plugins-6.0/libcounter.so
%{_libdir}/%{name}/plugins-6.0/libcs_date.so
%{_libdir}/%{name}/plugins-6.0/libdoppler.so
%{_libdir}/%{name}/plugins-6.0/libemugens.so
%{_libdir}/%{name}/plugins-6.0/libexciter.so
%{_libdir}/%{name}/plugins-6.0/libfareygen.so
%{_libdir}/%{name}/plugins-6.0/libfractalnoise.so
%{_libdir}/%{name}/plugins-6.0/libframebuffer.so
%{_libdir}/%{name}/plugins-6.0/libftsamplebank.so
%{_libdir}/%{name}/plugins-6.0/libgetftargs.so
%{_libdir}/%{name}/plugins-6.0/libgtf.so
%{_libdir}/%{name}/plugins-6.0/libimage.so
%{_libdir}/%{name}/plugins-6.0/libipmidi.so
%{_libdir}/%{name}/plugins-6.0/libjoystick.so
%{_libdir}/%{name}/plugins-6.0/libliveconv.so
%{_libdir}/%{name}/plugins-6.0/libmixer.so
%{_libdir}/%{name}/plugins-6.0/libpadsynth.so
%{_libdir}/%{name}/plugins-6.0/libplaterev.so
%{_libdir}/%{name}/plugins-6.0/libpmidi.so
%{_libdir}/%{name}/plugins-6.0/libpvsops.so
%{_libdir}/%{name}/plugins-6.0/libpy.so
%{_libdir}/%{name}/plugins-6.0/libquadbezier.so
%{_libdir}/%{name}/plugins-6.0/librtalsa.so
%{_libdir}/%{name}/plugins-6.0/librtpulse.so
%{_libdir}/%{name}/plugins-6.0/libscansyn.so
%{_libdir}/%{name}/plugins-6.0/libscugens.so
%{_libdir}/%{name}/plugins-6.0/libserial.so
%{_libdir}/%{name}/plugins-6.0/libselect.so
%{_libdir}/%{name}/plugins-6.0/libsignalflowgraph.so
%{_libdir}/%{name}/plugins-6.0/libstackops.so
%{_libdir}/%{name}/plugins-6.0/libstdutil.so
%{_libdir}/%{name}/plugins-6.0/libsterrain.so
%{_libdir}/%{name}/plugins-6.0/libsystem_call.so
%{_libdir}/%{name}/plugins-6.0/liburandom.so

%files devel
%{_includedir}/%{name}/
%{_libdir}/lib%{name}64.so
%{_libdir}/libcsnd6.so

%files -n python3-csound
%{python3_sitearch}/*

%if %{build_java}
%files java
%{_libdir}/lib_jcsound6.so
%{_libdir}/csnd6.jar
%{_javadir}/csnd.jar

%files javadoc
%{_javadocdir}/%{name}-java
%endif

%files fltk
%{_libdir}/%{name}/plugins-6.0/libwidgets.so

%files jack
%{_libdir}/%{name}/plugins-6.0/libjacko.so
%{_libdir}/%{name}/plugins-6.0/librtjack.so
%{_libdir}/%{name}/plugins-6.0/libjackTransport.so

%files fluidsynth
%{_libdir}/%{name}/plugins-6.0/libfluidOpcodes.so

%files dssi
%{_libdir}/%{name}/plugins-6.0/libdssi4cs.so

%files osc
%{_libdir}/%{name}/plugins-6.0/libosc.so

%files portaudio
%{_libdir}/%{name}/plugins-6.0/librtpa.so

%files virtual-keyboard
%{_libdir}/%{name}/plugins-6.0/libvirtual.so

%files wiimote
%{_libdir}/%{name}/plugins-6.0/libwiimote.so

%files doc
%doc html/
%doc examples/*


%changelog
* Thu Sep 03 2020 luigiwalser <luigiwalser> 6.15.0-1.mga8
+ Revision: 1621458
- 6.15.0
- drop lua subpackage

* Sat Feb 22 2020 daviddavid <daviddavid> 6.14.0-1.mga8
+ Revision: 1549432
- new version: 6.14.0

* Sun Feb 16 2020 umeabot <umeabot> 6.13.0-4.mga8
+ Revision: 1531075
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Mon Sep 09 2019 wally <wally> 6.13.0-3.mga8
+ Revision: 1439016
- rebuild for python3.8

* Sun Sep 01 2019 daviddavid <daviddavid> 6.13.0-2.mga8
+ Revision: 1436102
- make sure Python 3 is found and used

* Sun Sep 01 2019 daviddavid <daviddavid> 6.13.0-1.mga8
+ Revision: 1436093
- new version: 6.13.0
- port to Python 3

* Tue Jan 15 2019 luigiwalser <luigiwalser> 6.10.0-1.mga7
+ Revision: 1356970
- fix jack subpackage conflict with old csound due to moved file
- backport upstream patch to fix build with fluidsynth 2.0.x
- 6.10.0
- partial sync with fedora
- rebuild for fluidsynth

* Sun Sep 23 2018 umeabot <umeabot> 6.06-7.mga7
+ Revision: 1297340
- Mageia 7 Mass Rebuild

* Sat Jul 14 2018 wally <wally> 6.06-6.mga7
+ Revision: 1243587
- add aarch64 support
- add patch to fix build with lua5.2

* Tue Sep 12 2017 cjw <cjw> 6.06-5.mga7
+ Revision: 1153116
- add buildrequires libgomp-devel
- revert buildrequires pkgconfig(lua) to lua5.2-devel

* Wed Mar 01 2017 ghibo <ghibo> 6.06-4.mga6
+ Revision: 1088343
- Rebuilt against pulseaudio 10

* Fri Mar 11 2016 blino <blino> 6.06-3.mga6
+ Revision: 988886
- fix build with latest boost (patches from upstream)
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Sat Oct 10 2015 shlomif <shlomif> 6.06-1.mga6
+ Revision: 889172
- Add missing BR
- Add missing BR
- Fixes for the patching
- New version 6.06 - used the Fedora .spec as reference-thx.
+ daviddavid <daviddavid>
- rebuild for new tcl/tk 8.6.4
- fix python2 macros (fix build)

* Sun Aug 16 2015 fwang <fwang> 5.19.01-11.mga6
+ Revision: 865072
- rebuild for new fltk

* Sun Nov 30 2014 sander85 <sander85> 5.19.01-10.mga5
+ Revision: 800046
- Disable java

* Wed Oct 15 2014 umeabot <umeabot> 5.19.01-9.mga5
+ Revision: 750291
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 5.19.01-8.mga5
+ Revision: 726066
- rebuild for missing pythoneggs deps

* Wed Sep 24 2014 wally <wally> 5.19.01-7.mga5
+ Revision: 724218
- exclude %%_docdir from auto-requires

* Thu Sep 18 2014 umeabot <umeabot> 5.19.01-6.mga5
+ Revision: 693703
- Rebuild to fix library dependencies

* Tue Sep 16 2014 umeabot <umeabot> 5.19.01-5.mga5
+ Revision: 678604
- Mageia 5 Mass Rebuild

* Tue Aug 19 2014 luigiwalser <luigiwalser> 5.19.01-4.mga5
+ Revision: 665342
- drop gcj support (from fedora)
+ pterjan <pterjan>
- Rebuild for new Python

* Mon Oct 21 2013 umeabot <umeabot> 5.19.01-2.mga4
+ Revision: 539489
- Mageia 4 Mass Rebuild

* Sun Oct 06 2013 shlomif <shlomif> 5.19.01-1.mga4
+ Revision: 492285
- New version 5.19.01 - some updates to SPEC from Fedora

* Tue Jul 09 2013 fwang <fwang> 5.17.11-5.mga4
+ Revision: 451718
- rebuild for new boost

* Mon Jun 03 2013 fwang <fwang> 5.17.11-4.mga4
+ Revision: 435807
- rebuild for new libpng

* Fri Jan 11 2013 umeabot <umeabot> 5.17.11-3.mga3
+ Revision: 348368
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Nov 29 2012 malo <malo> 5.17.11-2.mga3
+ Revision: 322797
- update RPM group

* Mon Aug 06 2012 sander85 <sander85> 5.17.11-1.mga3
+ Revision: 279254
- New version: 5.17.11.
- Rediff patches 1,4,6,8 and 10.
- Drop patches 11-14.
- Fix build with bison 2.6.
- Switch BR to lua5.1-devel.
- Fill doc package.

* Tue Apr 24 2012 fwang <fwang> 5.13.0-7.mga2
+ Revision: 233147
- add patch fixing CVE-2012-210[678]
- drop linkflaggs
- try build with ldflags

* Sat Apr 07 2012 fwang <fwang> 5.13.0-5.mga2
+ Revision: 229474
- fix typo
- add upstream patch to fix CVE-2012-0270: two buffer overflow flaws in getnum()

* Mon Sep 19 2011 fwang <fwang> 5.13.0-4.mga2
+ Revision: 145280
- rebuild for new libpng

* Mon Jul 11 2011 ahmad <ahmad> 5.13.0-3.mga2
+ Revision: 122089
- Move libcsnd.so to the -devel package

* Mon Jul 11 2011 fwang <fwang> 5.13.0-2.mga2
+ Revision: 122088
- rebuild for new fltk

* Sun Jul 10 2011 ahmad <ahmad> 5.13.0-1.mga2
+ Revision: 121758
- Update the manual sources (from the Fedora src.rpm)
- Update to 5.13.0
- Rediff patch0,1,2,4,6,7,10
- Drop patch9, fixed upstream
- Add BR flex, bison
- Update the file list

* Sun Jul 03 2011 fwang <fwang> 5.11-8.mga2
+ Revision: 117572
- we use 8.5 now by default
- rebuild for new csound

* Sun Feb 20 2011 eandry <eandry> 5.11-7.mga1
+ Revision: 54675
- drop buildroot
- bump release for upgrade
- imported package csound


* Sun Nov 07 2010 Jani Välimaa <wally@mandriva.org> 5.11-6mdv2011.0
+ Revision: 594452
- recognize python 2.7
- rebuild for python 2.7

* Sat Jan 16 2010 Funda Wang <fwang@mandriva.org> 5.11-5mdv2010.1
+ Revision: 492228
- rebuild for new libjpegv8

* Fri Jan 08 2010 Frederik Himpe <fhimpe@mandriva.org> 5.11-4mdv2010.1
+ Revision: 487725
- rebuild

* Sun Jan 03 2010 Emmanuel Andry <eandry@mandriva.org> 5.11-3mdv2010.1
+ Revision: 486025
- rebuild for new fltk

* Thu Nov 26 2009 Jérôme Brenier <incubusss@mandriva.org> 5.11-2mdv2010.1
+ Revision: 470418
-jack subpackage : requires jackit instead of jack-audio-connection-kit

* Sat Nov 07 2009 Frederik Himpe <fhimpe@mandriva.org> 5.11-1mdv2010.1
+ Revision: 462689
- update to new version 5.11

* Thu Oct 08 2009 Guillaume Rousse <guillomovitch@mandriva.org> 5.10.1-3mdv2010.0
+ Revision: 456003
- fix groups
- rename -manual subpackage to -doc
- don't make it noarch, it doesn't work

* Sun Sep 20 2009 Nicolas Lécureuil <nlecureuil@mandriva.com> 5.10.1-2mdv2010.0
+ Revision: 446059
- Fix groups
- Fix obsoletes
- Let my "monk" packaging habits fix my spec files :)
- Fix file list
- import csound

